Package 'ggsegGlasser'

Title: Glasser Atlas for the 'ggsegverse' Ecosystem
Description: Glasser multi-modal cortical parcellation (HCP) atlas for the 'ggseg' ecosystem. Provides a unified 'ggseg_atlas' object with 2D polygon geometry for use with 'ggseg'.
Authors: Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>), Didac Vidal-PiƱeiro [aut] (ORCID: <https://orcid.org/0000-0001-9997-9156>)
Maintainer: Athanasia Mo Mowinckel <[email protected]>
License: MIT + file LICENSE
Version: 2.0.3
Built: 2026-05-23 09:18:15 UTC
Source: https://github.com/ggsegverse/ggsegGlasser

Help Index


Glasser Multi-Modal Cortical Parcellation (HCP)

Description

Brain atlas for the Glasser cortical parcellation with 361 regions based on the Human Connectome Project multi-modal parcellation. Contains 2D polygon geometry for ggseg::geom_brain().

Usage

glasser()

Value

A ggseg.formats::ggseg_atlas object (cortical).

References

Glasser MF, Coalson TS, Robinson EC, Hacker CD, Harwell J, Yacoub E, Ugurbil K, Andersson J, Beckmann CF, Jenkinson M, Smith SM, Van Essen DC (2016). A multi-modal parcellation of human cerebral cortex. Nature, 536(7615):171-178. doi:10.1038/nature18933

Examples

glasser()
plot(glasser())